pub fn set_max_decompressed_size_bytes(size: usize)Expand description
Override the global decompressed payload size cap. Must be called before any sources start.
Panics
Panics if called more than once, as the global cap may only be initialized a single time.